@@ -10,7 +10,8 @@
  * Distributed under the GNU GPL v3. For full terms see the file docs/COPYING.
  *
  * @ingroup api_v1_temporaryFiles
+ *
  * @brief Handle API requests for temporary file uploading.
  */
-import('lib.pkp.api.v1.temporaryFiles.PKPTemporaryFilesHandler');
-return new PKPTemporaryFilesHandler();
+
+return new \PKP\API\v1\temporaryFiles\PKPTemporaryFilesHandler();
