@@ -323,7 +323,7 @@ class MetricsMigration extends \PKP\migration\Migration
             $table->string('city', 255)->default('');
             $table->string('load_id', 50);
 
-            $table->index(['load_id', 'context_id', 'ip'], 'ust_load_id_context_id_ip');
+            $table->index(['load_id', 'context_id', 'ip', 'user_agent', 'canonical_url'], 'ust_load_id_context_id_ip_ua_url');
         });
 
         // Usage stats unique book and chapter item investigations temporary records
@@ -364,7 +364,7 @@ class MetricsMigration extends \PKP\migration\Migration
             $table->string('city', 255)->default('');
             $table->string('load_id', 50);
 
-            $table->index(['load_id', 'context_id', 'ip'], 'usii_load_id_context_id_ip');
+            $table->index(['load_id', 'context_id', 'ip', 'user_agent'], 'usii_load_id_context_id_ip_ua');
         });
 
         // Usage stats unique book and chapter item requests temporary records
@@ -405,7 +405,7 @@ class MetricsMigration extends \PKP\migration\Migration
             $table->string('city', 255)->default('');
             $table->string('load_id', 50);
 
-            $table->index(['load_id', 'context_id', 'ip'], 'usir_load_id_context_id_ip');
+            $table->index(['load_id', 'context_id', 'ip', 'user_agent'], 'usir_load_id_context_id_ip_ua');
         });
 
         // Usage stats unique title investigations temporary records
@@ -445,7 +445,7 @@ class MetricsMigration extends \PKP\migration\Migration
             $table->string('city', 255)->default('');
             $table->string('load_id', 50);
 
-            $table->index(['load_id', 'context_id', 'ip'], 'usti_load_id_context_id_ip');
+            $table->index(['load_id', 'context_id', 'ip', 'user_agent'], 'usti_load_id_context_id_ip_ua');
         });
 
         // Usage stats unique title requests temporary records
@@ -486,7 +486,7 @@ class MetricsMigration extends \PKP\migration\Migration
             $table->string('city', 255)->default('');
             $table->string('load_id', 50);
 
-            $table->index(['load_id', 'context_id', 'ip'], 'ustr_load_id_context_id_ip');
+            $table->index(['load_id', 'context_id', 'ip', 'user_agent'], 'ustr_load_id_context_id_ip_ua');
         });
 
         // Usage stats institution temporary records
