@@ -3,8 +3,8 @@
 /**
  * @file classes/publication/Publication.php
  *
- * Copyright (c) 2016-2021 Simon Fraser University
- * Copyright (c) 2003-2021 John Willinsky
+ * Copyright (c) 2016-2024 Simon Fraser University
+ * Copyright (c) 2003-2024 John Willinsky
  * Distributed under the GNU GPL v3. For full terms see the file docs/COPYING.
  *
  * @class Publication
@@ -45,12 +45,37 @@ class Publication extends PKPPublication
         return join(__('common.commaListSeparator') . ' ', $editorNames);
     }
 
+    /**
+     * Get the URL to a cover image
+     *
+     * @param int $contextId
+     * @param string $preferredLocale Return the cover image in a specified locale.
+     *
+     * @return string
+     */
+    public function getCoverImageUrl($contextId, $preferredLocale = null)
+    {
+        $coverImage = $this->getData('coverImage', $preferredLocale);
+
+        if (!$coverImage) {
+            return Application::get()->getRequest()->getBaseUrl() . '/templates/images/book-default.png';
+        }
+
+        $publicFileManager = new PublicFileManager();
+
+        return join('/', [
+            Application::get()->getRequest()->getBaseUrl(),
+            $publicFileManager->getContextFilesPath($contextId),
+            $coverImage['uploadName'],
+        ]);
+    }
+
     /**
      * Get the URL to a localized cover image
      *
      * @param int $contextId
      * @param string $preferredLocale Return the cover image in a specified locale.
-     * 
+     *
      * @return string
      */
     public function getLocalizedCoverImageUrl($contextId, $preferredLocale = null)
