@@ -7,8 +7,8 @@
 ;
 ; config.TEMPLATE.inc.php
 ;
-; Copyright (c) 2014-2021 Simon Fraser University
-; Copyright (c) 2003-2021 John Willinsky
+; Copyright (c) 2014-2024 Simon Fraser University
+; Copyright (c) 2003-2024 John Willinsky
 ; Distributed under the GNU GPL v3. For full terms see the file docs/COPYING.
 ;
 ; OMP Configuration settings.
@@ -93,7 +93,7 @@ allow_url_fopen = Off
 ; Example3: URLs that map to a subdomain.
 ;    Example3: base_url[myOtherPress] = http://myOtherPress.example.com
 
-; Generate RESTful URLs using mod_rewrite.  This requires the
+; Generate RESTful URLs using mod_rewrite. This requires the
 ; rewrite directive to be enabled in your .htaccess or httpd.conf.
 ; See FAQ for more details.
 restful_urls = Off
@@ -102,29 +102,42 @@ restful_urls = Off
 ; See docs/README.md for more details. The list should be JSON-formatted.
 ; An empty string indicates that all hosts should be trusted (not recommended!)
 ; Example:
-; allowed_hosts = '["myjournal.tld", "anotherjournal.tld", "mylibrary.tld"]'
+; allowed_hosts = '["mypress.tld", "anotherpress.tld", "mylibrary.tld"]'
 allowed_hosts = ''
 
 ; Allow the X_FORWARDED_FOR header to override the REMOTE_ADDR as the source IP
-; Set this to "On" if you are behind a reverse proxy and you control the X_FORWARDED_FOR
+; Set this to "On" if you are behind a reverse proxy and you control the
+; X_FORWARDED_FOR header.
 ; Warning: This defaults to "On" if unset for backwards compatibility.
 trust_x_forwarded_for = Off
 
-; Set the following parameter to off if you want to work with the uncompiled
-; (non-minified) JavaScript source for debugging or if you are working off a
-; development branch without compiled JavaScript.
+; Display a message on the site admin and press manager user home pages if there is an upgrade available
+show_upgrade_warning = On
+
+; Set the following parameter to off if you want to work with the uncompiled (non-minified) JavaScript
+; source for debugging or if you are working off a development branch without compiled JavaScript.
 enable_minified = On
 
 ; Provide a unique site ID and OAI base URL to PKP for statistics and security
 ; alert purposes only.
 enable_beacon = On
 
-; The number of days a new user has to validate their account
-; A new user account will be expired and removed if this many days have passed since the user registered
-; their account, and they have not validated their account or logged in. If the user_validation_period is set to
-; 0, unvalidated accounts will never be removed. Use this setting to automatically remove bot registrations.
+; Set this to "On" if you would like to only have a single, site-wide Privacy
+; Statement, rather than a separate Privacy Statement for each press. Setting
+; this to "Off" will allow you to enter a site-wide Privacy Statement as well
+; as separate Privacy Statements for each press.
+sitewide_privacy_statement = Off
+
+; The number of days a new user has to validate their account.
+; A new user account will be removed if this many days have passed since the user registered
+; their account, and they have not validated their account or logged in. If set to 0,
+; unvalidated accounts will never be removed. Use this setting to automatically remove bot registrations.
 user_validation_period = 28
 
+; Turn sandbox mode to On in order to prevent the software from interacting with outside systems.
+; Use this for development or testing purposes.
+sandbox = Off
+
 
 ;;;;;;;;;;;;;;;;;;;;;
 ; Database Settings ;
@@ -148,6 +161,7 @@ name = omp
 ; Enable database debug output (very verbose!)
 debug = Off
 
+
 ;;;;;;;;;;;;;;;;;;
 ; Cache Settings ;
 ;;;;;;;;;;;;;;;;;;
@@ -159,7 +173,6 @@ debug = Off
 ; - file: Use file-based caching; configured below
 ; - none: Use no caching. This may be extremely slow.
 ; This setting affects locale data, press settings, and plugin settings.
-
 cache = file
 
 ; Enable memcache support
@@ -179,7 +192,7 @@ memcache_port = 11211
 ;
 ; When using web_cache, configure a tool to periodically clear out cache files
 ; such as CRON. For example, configure it to run the following command:
-; find .../ojs/cache -maxdepth 1 -name wc-\*.html -mtime +1 -exec rm "{}" ";"
+; find .../omp/cache -maxdepth 1 -name wc-\*.html -mtime +1 -exec rm "{}" ";"
 web_cache = Off
 web_cache_hours = 1
 
@@ -224,10 +237,6 @@ public_user_dir_size = 5000
 ; Permissions mask for created files and directories
 umask = 0022
 
-; The minimum percentage similarity between filenames that should be considered
-; a possible revision
-filename_revision_match = 70
-
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ; Fileinfo (MIME) Settings ;
@@ -251,9 +260,10 @@ force_ssl = Off
 force_login_ssl = Off
 
 ; This check will invalidate a session if the user's IP address changes.
-; Enabling this option provides some amount of additional security, but may
-; cause problems for users behind a proxy farm (e.g., AOL).
-session_check_ip = Off
+; Enabling this option provides some additional security, but may cause
+; login problems for some users (e.g. if a user IP is changed frequently
+; by a server or network configuration).
+session_check_ip = On
 
 ; The encryption (hashing) algorithm to use for encrypting user passwords
 ; Valid values are: md5, sha1
@@ -282,6 +292,7 @@ allowed_title_html = "b,i,u,sup,sub"
 
 ;N.b.: The implicit_auth parameter has been removed in favor of plugin implementations such as shibboleth
 
+
 ;;;;;;;;;;;;;;;;;;
 ; Email Settings ;
 ;;;;;;;;;;;;;;;;;;
@@ -344,7 +355,7 @@ sendmail_path = "/usr/sbin/sendmail -bs"
 ; If enabled, email addresses must be validated before login is possible.
 require_validation = Off
 
-; Maximum number of days before an unvalidated account expires and is deleted
+; The number of days a user has to validate their account before their access key expires.
 validation_timeout = 14
 
 
@@ -361,9 +372,6 @@ min_word_length = 3
 ; are fetched and merged to provide results for searches with several keywords.
 results_per_keyword = 500
 
-; The number of hours for which keyword search results are cached.
-result_cache_hours = 1
-
 ; Paths to helper programs for indexing non-text files.
 ; Programs are assumed to output the converted text to stdout, and "%s" is
 ; replaced by the file argument.
@@ -398,6 +406,9 @@ oai = On
 ; Changing this setting may affect existing clients and is not recommended.
 repository_id = omp.pkp.sfu.ca
 
+; Maximum number of records per request to serve via OAI
+oai_max_records = 100
+
 
 ;;;;;;;;;;;;;;;;;;;;;;
 ; Interface Settings ;
@@ -406,7 +417,7 @@ repository_id = omp.pkp.sfu.ca
 [interface]
 
 ; Number of items to display per page; can be overridden on a per-press basis
-items_per_page = 50
+items_per_page = 25
 
 ; Number of page links to display; can be overridden on a per-press basis
 page_links = 10
@@ -422,10 +433,10 @@ page_links = 10
 recaptcha = off
 
 ; Public key for reCaptcha (see http://www.google.com/recaptcha)
-; recaptcha_public_key = your_public_key
+recaptcha_public_key = your_public_key
 
 ; Private key for reCaptcha (see http://www.google.com/recaptcha)
-; recaptcha_private_key = your_private_key
+recaptcha_private_key = your_private_key
 
 ; Whether or not to use Captcha on user registration
 captcha_on_register = on
@@ -436,6 +447,7 @@ captcha_on_login = on
 ; Validate the hostname in the ReCaptcha response
 recaptcha_enforce_hostname = Off
 
+
 ;;;;;;;;;;;;;;;;;;;;;
 ; External Commands ;
 ;;;;;;;;;;;;;;;;;;;;;
@@ -444,23 +456,16 @@ recaptcha_enforce_hostname = Off
 
 ; These are paths to (optional) external binaries used in
 ; certain plug-ins or advanced program features.
-
 ; Using full paths to the binaries is recommended.
 
 ; tar (used in backup plugin, translation packaging)
 tar = /bin/tar
 
-; egrep (used in copyAccessLogFileTool)
-egrep = /bin/egrep
-
-; gzip (used in FileManager)
-gzip = /bin/gzip
-
-; On systems that do not have PHP4's Sablotron/xsl or PHP5's libxsl/xslt
-; libraries installed, or for those who require a specific XSLT processor,
-; you may enter the complete path to the XSLT renderer tool, with any
-; required arguments. Use %xsl to substitute the location of the XSL
-; stylesheet file, and %xml for the location of the XML source file; eg:
+; On systems that do not have libxsl/xslt libraries installed, or for those who
+; require a specific XSLT processor, you may enter the complete path to the
+; XSLT renderer tool, with any required arguments. Use %xsl to substitute the
+; location of the XSL stylesheet file, and %xml for the location of the XML
+; source file; eg:
 ; /usr/bin/java -jar ~/java/xalan.jar -IN %xml -XSL %xsl %params
 ; See xslt_parameter_option below for information on the %params token.
 xslt_command = ""
@@ -504,11 +509,6 @@ deprecation_warnings = Off
 ; Log web service request information for debugging
 log_web_service_info = Off
 
-; declare a cainfo path if a certificate other than PHP's default should be used for curl calls.
-; This setting overrides the 'curl.cainfo' parameter of the php.ini configuration file.
-[curl]
-; cainfo = ""
-
 
 ;;;;;;;;;;;;;;;;;;;;;;;
 ; Job Queues Settings ;
@@ -522,16 +522,13 @@ default_connection = "database"
 ; Default queue to use when a job is added to the queue
 default_queue = "queue"
 
-; Whether or not to turn on the built-in job runner
-;
+; Whether or not to turn on the built-in job runner.
 ; When enabled, jobs will be processed at the end of each web
 ; request to the application.
-;
 ; Use of the built-in job runner is highly discouraged for high-volume
 ; sites. Instead, a worker daemon or cron job should be configured
 ; to process jobs off the application's main thread.
-;
-; See: https://docs.pkp.sfu.ca/admin-guide/en/advanced-jobs
+; See: https://docs.pkp.sfu.ca/admin-guide/en/deploy-jobs
 ;
 job_runner = On
 
@@ -541,22 +538,18 @@ job_runner_max_jobs = 30
 
 ; The maximum number of seconds the built-in job runner should spend
 ; running jobs in a single request.
-;
 ; This should be less than the max_execution_time the server has
 ; configured for PHP.
-;
 ; Lower this setting if jobs are failing due to timeouts.
 job_runner_max_execution_time = 30
 
-; The maximum consumerable memory that should be spent by the built-in
+; The maximum consumable memory that should be spent by the built-in
 ; job runner when running jobs.
 ;
 ; Set as a percentage, such as 80%:
-;
 ; job_runner_max_memory = 80
 ;
 ; Or set as a fixed value in megabytes:
-;
 ; job_runner_max_memory = 128M
 ;
 ; When setting a fixed value in megabytes, this should be less than the
