@@ -3,8 +3,8 @@
 /**
  * @file controllers/grid/settings/series/SeriesGridHandler.php
  *
- * Copyright (c) 2014-2024 Simon Fraser University
- * Copyright (c) 2003-2024 John Willinsky
+ * Copyright (c) 2014-2025 Simon Fraser University
+ * Copyright (c) 2003-2025 John Willinsky
  * Distributed under the GNU GPL v3. For full terms see the file docs/COPYING.
  *
  * @class SeriesGridHandler
@@ -20,7 +20,6 @@ use APP\controllers\grid\settings\series\form\SeriesForm;
 use APP\core\Application;
 use APP\core\Request;
 use APP\facades\Repo;
-use APP\notification\Notification;
 use APP\notification\NotificationManager;
 use PKP\context\SubEditorsDAO;
 use PKP\controllers\grid\feature\OrderGridItemsFeature;
@@ -98,7 +97,7 @@ class SeriesGridHandler extends SetupGridHandler
                         ->toArray()
                 )
                 ->getMany();
-            if ($assignedSeriesEditors->empty()) {
+            if ($assignedSeriesEditors->isEmpty()) {
                 $editorsString = __('common.none');
             } else {
                 $editors = [];
