@@ -166,7 +166,10 @@ class PKPNavigationMenuService
         // Conditionally hide some items
         switch ($menuItemType) {
             case NavigationMenuItem::NMI_TYPE_ANNOUNCEMENTS:
-                $navigationMenuItem->setIsDisplayed($context && $context->getData('enableAnnouncements'));
+                $navigationMenuItem->setIsDisplayed(
+                    ($context && $context->getData('enableAnnouncements'))
+                    || (!$context && $request->getSite()->getData('enableAnnouncements'))
+                );
                 break;
             case NavigationMenuItem::NMI_TYPE_EDITORIAL_TEAM:
                 $navigationMenuItem->setIsDisplayed($context && $context->getLocalizedData('editorialTeam'));
@@ -188,9 +191,6 @@ class PKPNavigationMenuService
             case NavigationMenuItem::NMI_TYPE_ADMINISTRATION:
                 $navigationMenuItem->setIsDisplayed($isUserLoggedIn && $currentUser->hasRole([Role::ROLE_ID_SITE_ADMIN], PKPApplication::CONTEXT_SITE));
                 break;
-            case NavigationMenuItem::NMI_TYPE_SEARCH:
-                $navigationMenuItem->setIsDisplayed($context);
-                break;
             case NavigationMenuItem::NMI_TYPE_PRIVACY:
                 $navigationMenuItem->setIsDisplayed($context && $context->getLocalizedData('privacyStatement'));
                 break;
@@ -526,7 +526,7 @@ class PKPNavigationMenuService
      */
     public function transformNavMenuItemTitle($templateMgr, &$navigationMenuItem)
     {
-        $this->setNMITitleLocalized($navigationMenuItem);
+        $this->setAllNMILocalizedTitles($navigationMenuItem);
 
         $title = $navigationMenuItem->getLocalizedTitle();
         $prefix = '{$';
@@ -631,6 +631,8 @@ class PKPNavigationMenuService
             foreach ($supportedFormLocales as $supportedFormLocale => $supportedFormLocaleValue) {
                 if ($localizedTitle = $nmi->getTitle($supportedFormLocale)) {
                     $nmi->setTitle($localizedTitle, $supportedFormLocale);
+                } elseif ($nmi->getTitleLocaleKey() === '{$loggedInUsername}') {
+                    $nmi->setTitle($nmi->getTitleLocaleKey(), Locale::getLocale());
                 } else {
                     $nmi->setTitle(__($nmi->getTitleLocaleKey(), [], $supportedFormLocale), $supportedFormLocale);
                 }
