@@ -35,6 +35,7 @@ class PKPSchemaService
     public const SCHEMA_DECISION = 'decision';
     public const SCHEMA_EMAIL_TEMPLATE = 'emailTemplate';
     public const SCHEMA_GALLEY = 'galley';
+    public const SCHEMA_HIGHLIGHT = 'highlight';
     public const SCHEMA_INSTITUTION = 'institution';
     public const SCHEMA_ISSUE = 'issue';
     public const SCHEMA_PUBLICATION = 'publication';
@@ -66,6 +67,8 @@ class PKPSchemaService
      */
     public function get($schemaName, $forceReload = false)
     {
+        Hook::run('Schema::get::before::' . $schemaName, [&$forceReload]);
+
         if (!$forceReload && array_key_exists($schemaName, $this->_schemas)) {
             return $this->_schemas[$schemaName];
         }
