@@ -24,7 +24,6 @@ use Carbon\Carbon;
 use Illuminate\Console\Concerns\InteractsWithIO;
 use Illuminate\Console\OutputStyle;
 use Illuminate\Contracts\Queue\Job;
-use Illuminate\Http\Request;
 use Illuminate\Http\Resources\Json\JsonResource;
 use Illuminate\Queue\Events\JobFailed;
 use Illuminate\Queue\Events\JobProcessed;
@@ -76,15 +75,16 @@ class commandInterface
 class commandJobs extends CommandLineTool
 {
     protected const AVAILABLE_OPTIONS = [
-        'list' => 'admin.cli.tool.jobs.available.options.list.description',
-        'purge' => 'admin.cli.tool.jobs.available.options.purge.description',
-        'test' => 'admin.cli.tool.jobs.available.options.test.description',
-        'total' => 'admin.cli.tool.jobs.available.options.total.description',
-        'help' => 'admin.cli.tool.jobs.available.options.help.description',
-        'run' => 'admin.cli.tool.jobs.available.options.run.description',
-        'work' => 'admin.cli.tool.jobs.available.options.work.description',
-        'failed' => 'admin.cli.tool.jobs.available.options.failed.description',
-        'usage' => 'admin.cli.tool.jobs.available.options.usage.description',
+        'list'      => 'admin.cli.tool.jobs.available.options.list.description',
+        'purge'     => 'admin.cli.tool.jobs.available.options.purge.description',
+        'test'      => 'admin.cli.tool.jobs.available.options.test.description',
+        'total'     => 'admin.cli.tool.jobs.available.options.total.description',
+        'help'      => 'admin.cli.tool.jobs.available.options.help.description',
+        'run'       => 'admin.cli.tool.jobs.available.options.run.description',
+        'work'      => 'admin.cli.tool.jobs.available.options.work.description',
+        'failed'    => 'admin.cli.tool.jobs.available.options.failed.description',
+        'restart'   => 'admin.cli.tool.jobs.available.options.restart.description',
+        'usage'     => 'admin.cli.tool.jobs.available.options.usage.description',
     ];
 
     protected const CURRENT_PAGE = 'current';
@@ -234,7 +234,7 @@ class commandJobs extends CommandLineTool
 
         if (in_array('--redispatch', $parameterList) || ($jobIds = $this->getParameterValue('redispatch'))) {
             $jobsCount = Repo::failedJob()->redispatchToQueue(
-                $this->getParameterValue('--queue'),
+                $this->getParameterValue('queue'),
                 collect(explode(',', $jobIds ?? ''))
                     ->filter()
                     ->map(fn ($item) => (int)$item)
@@ -246,7 +246,7 @@ class commandJobs extends CommandLineTool
 
         if (in_array('--clear', $parameterList) || ($jobIds = $this->getParameterValue('clear'))) {
             $jobsCount = Repo::failedJob()->deleteJobs(
-                $this->getParameterValue('--queue'),
+                $this->getParameterValue('queue'),
                 collect(explode(',', $jobIds ?? ''))
                     ->filter()
                     ->map(fn ($item) => (int)$item)
@@ -261,6 +261,21 @@ class commandJobs extends CommandLineTool
         $this->list();
     }
 
+    /**
+     * Signal the queue worker to quit gracefully
+     */
+    protected function restart(): void
+    {
+        $cache = app()->get("cache.store"); /** @var \Illuminate\Contracts\Cache\Repository $cache */
+
+        $cache->forever('illuminate:queue:restart', Carbon::now()->getTimestamp());
+
+        $this
+            ->getCommandInterface()
+            ->getOutput()
+            ->info(__('admin.cli.tool.jobs.available.options.restart.confirm'));
+    }
+
     /**
      * List all queued jobs
      */
@@ -282,7 +297,7 @@ class commandJobs extends CommandLineTool
         $this->total();
 
         $this->getCommandInterface()->table(
-            $this->getListTableFormat(), 
+            $this->getListTableFormat(),
             $data
                 ->map(fn(JsonResource $job) => $job->toArray(app('request')))
                 ->toArray()
@@ -375,6 +390,12 @@ class commandJobs extends CommandLineTool
             return;
         }
 
+        if (Config::getVar('general', 'sandbox', false)) {
+            $this->getCommandInterface()->getOutput()->error(__('admin.cli.tool.jobs.sandbox.message'));
+            error_log(__('admin.cli.tool.jobs.sandbox.message'));
+            return;
+        }
+
         $connection = $parameterList['connection'] ?? Config::getVar('queues', 'default_connection', 'database');
         $queue = $parameterList['queue'] ?? Config::getVar('queues', 'default_queue', 'queue');
 
@@ -401,6 +422,12 @@ class commandJobs extends CommandLineTool
             return;
         }
 
+        if (Config::getVar('general', 'sandbox', false)) {
+            $this->getCommandInterface()->getOutput()->error(__('admin.cli.tool.jobs.sandbox.message'));
+            error_log(__('admin.cli.tool.jobs.sandbox.message'));
+            return;
+        }
+
         $parameterList = $this->getParameterList();
 
         $queue = $parameterList['queue'] ?? Config::getVar('queues', 'default_queue', 'queue');
@@ -511,17 +538,17 @@ class commandJobs extends CommandLineTool
         $workerConfig = new WorkerConfiguration();
 
         return [
-            'name' => $this->getParameterValue('--name', $workerConfig->getName()),
-            'backoff' => $this->getParameterValue('--backoff', $workerConfig->getBackoff()),
-            'memory' => $this->getParameterValue('--memory', $workerConfig->getMemory()),
-            'timeout' => $this->getParameterValue('--timeout', $workerConfig->getTimeout()),
-            'sleep' => $this->getParameterValue('--sleep', $workerConfig->getSleep()),
-            'maxTries' => $this->getParameterValue('--tries', $workerConfig->getMaxTries()),
-            'force' => $this->getParameterValue('--force', in_array('--force', $parameters) ? true : $workerConfig->getForce()),
-            'stopWhenEmpty' => $this->getParameterValue('--stop-when-empty', in_array('--stop-when-empty', $parameters) ? true : $workerConfig->getStopWhenEmpty()),
-            'maxJobs' => $this->getParameterValue('--max-jobs', $workerConfig->getMaxJobs()),
-            'maxTime' => $this->getParameterValue('--max-time', $workerConfig->getMaxTime()),
-            'rest' => $this->getParameterValue('--rest', $workerConfig->getRest()),
+            'name' => $this->getParameterValue('name', $workerConfig->getName()),
+            'backoff' => $this->getParameterValue('backoff', $workerConfig->getBackoff()),
+            'memory' => $this->getParameterValue('memory', $workerConfig->getMemory()),
+            'timeout' => $this->getParameterValue('timeout', $workerConfig->getTimeout()),
+            'sleep' => $this->getParameterValue('sleep', $workerConfig->getSleep()),
+            'maxTries' => $this->getParameterValue('tries', $workerConfig->getMaxTries()),
+            'force' => $this->getParameterValue('force', in_array('force', $parameters) ? true : $workerConfig->getForce()),
+            'stopWhenEmpty' => $this->getParameterValue('stop-when-empty', in_array('stop-when-empty', $parameters) ? true : $workerConfig->getStopWhenEmpty()),
+            'maxJobs' => $this->getParameterValue('max-jobs', $workerConfig->getMaxJobs()),
+            'maxTime' => $this->getParameterValue('max-time', $workerConfig->getMaxTime()),
+            'rest' => $this->getParameterValue('rest', $workerConfig->getRest()),
         ];
     }
 
