@@ -3,7 +3,7 @@
 /**
  * @defgroup pages_gateway Gateway Pages
  */
- 
+
 /**
  * @file pages/gateway/index.php
  *
@@ -12,16 +12,14 @@
  * Distributed under the GNU GPL v3. For full terms see the file docs/COPYING.
  *
  * @ingroup pages_gateway
- * @brief Handle gateway interaction requests. 
+ *
+ * @brief Handle gateway interaction requests.
  *
  */
 
 switch ($op) {
-	case 'index':
-	case 'plugin':
-		define('HANDLER_CLASS', 'GatewayHandler');
-		import('pages.gateway.GatewayHandler');
-		break;
+    case 'index':
+    case 'plugin':
+        define('HANDLER_CLASS', 'APP\pages\gateway\GatewayHandler');
+        break;
 }
-
-
