@@ -12,20 +12,18 @@
  * Distributed under the GNU GPL v3. For full terms see the file docs/COPYING.
  *
  * @ingroup pages_information
+ *
  * @brief Handle information requests.
  *
  */
 
 switch ($op) {
-	case 'index':
-	case 'readers':
-	case 'authors':
-	case 'librarians':
-	case 'competingInterestPolicy':
-	case 'sampleCopyrightWording':
-		define('HANDLER_CLASS', 'InformationHandler');
-		import('pages.information.InformationHandler');
-		break;
+    case 'index':
+    case 'readers':
+    case 'authors':
+    case 'librarians':
+    case 'competingInterestPolicy':
+    case 'sampleCopyrightWording':
+        define('HANDLER_CLASS', 'APP\pages\information\InformationHandler');
+        break;
 }
-
-
