@@ -7,21 +7,19 @@
 /**
  * @file pages/manageCatalog/index.php
  *
- * Copyright (c) 2014-2020 Simon Fraser University
- * Copyright (c) 2003-2020 John Willinsky
+ * Copyright (c) 2014-2021 Simon Fraser University
+ * Copyright (c) 2003-2021 John Willinsky
  * Distributed under the GNU GPL v3. For full terms see the file docs/COPYING.
  *
  * @ingroup pages_catalog
+ *
  * @brief Handle requests for catalog management functions.
  *
  */
 
 switch ($op) {
-	case 'index':
-	case 'homepage':
-		define('HANDLER_CLASS', 'ManageCatalogHandler');
-		import('pages.manageCatalog.ManageCatalogHandler');
-		break;
+    case 'index':
+    case 'homepage':
+        define('HANDLER_CLASS', 'APP\pages\manageCatalog\ManageCatalogHandler');
+        break;
 }
-
-
